@@ -1,5 +1,5 @@
 /* ADCD - A Diminutive CD player for Linux/GNU
-   Copyright (C) 2004-2022 Antonio Diaz Diaz.
+   Copyright (C) 2004-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ CD::CD( const char * const filename )
   if( filedes < 0 )
     {
     std::fprintf( stderr, "adcd: cannot open '%s' in non-blocking mode.\n", filename );
-    std::fprintf( stderr, "Please, verify if you have permission to read device '%s'\n", filename );
+    std::fprintf( stderr, "Please, check whether you have permission to read device '%s'\n", filename );
     exit( 1 );
     }
   read_status();
